@@ -9,7 +9,7 @@ use base 'Mojo::Base';
 use overload '""' => sub { shift->to_string }, fallback => 1;
 use bytes;
 
-__PACKAGE__->attr(raw_length => (chained => 1, default => 0));
+__PACKAGE__->attr('raw_length', default => 0);
 
 sub new {
     my $self = shift->SUPER::new();
@@ -36,7 +36,7 @@ sub get_line {
     my $self = shift;
 
     # No full line in buffer
-    return undef unless $self->{buffer} =~ /\x0d?\x0a/;
+    return unless $self->{buffer} =~ /\x0d?\x0a/;
 
     # Locate line ending
     my $pos = index $self->{buffer}, "\x0a";
@@ -59,7 +59,7 @@ sub remove {
     return substr $self->{buffer}, 0, $length, '';
 }
 
-sub to_string { return shift->{buffer} || '' }
+sub to_string { shift->{buffer} || '' }
 
 1;
 __END__
@@ -80,12 +80,11 @@ Mojo::Buffer - A Simple In-Memory Buffer
 =head1 DESCRIPTION
 
 L<Mojo::Buffer> is a simple in-memory buffer.
-Functionality includes keeping track of the cumulative raw character length
-that has been in the buffer.
-Content may removed from the buffer by line or character count.
 
 =head1 ATTRIBUTES
 
+L<Mojo::Buffer> implements the following attributes.
+
 =head2 C<length>
 
     my $length = $buffer->length;
@@ -94,9 +93,6 @@ Content may removed from the buffer by line or character count.
 
     my $raw_length = $buffer->raw_length;
 
-Returns the cumulative length of the buffer.
-It never decreases.
-
 =head1 METHODS
 
 L<Mojo::Buffer> inherits all methods from L<Mojo::Base> and implements
@@ -107,37 +103,25 @@ the following new ones.
     my $buffer = Mojo::Buffer->new;
     my $buffer = Mojo::Buffer->new('foobarbaz');
 
-Returns a new L<Mojo::Buffer> object, and possibly adds content to it.
-
 =head2 C<add_chunk>
 
     $buffer = $buffer->add_chunk('foo');
 
-Returns the invocant and adds additional content to the buffer.
-
 =head2 C<empty>
 
     my $string = $buffer->empty;
 
-Returns the whole content of the buffer and empties it.
-
 =head2 C<get_line>
 
    my $line = $buffer->get_line;
 
-Returns a whole line if a C<newline> is present in the buffer or undef, even
-if there is content in the buffer.
-
 =head2 C<remove>
 
     my $string = $buffer->remove(4);
 
-Returns and removes a specific number of bytes from the buffer.
-
 =head2 C<to_string>
 
     my $string = $buffer->to_string;
-
-Returns the whole buffer content at once.
+    my $string = "$buffer";
 
 =cut
