@@ -15,12 +15,12 @@ sub build {
     return '' if $self->is_done;
 
     # Shortcut
-    return undef unless defined $chunk;
+    return unless defined $chunk;
 
     my $chunk_length = length $chunk;
 
     # Trailing headers?
-    my $headers = 1 if ref $chunk && $chunk->isa('Mojo::Headers');
+    my $headers = ref $chunk && $chunk->isa('Mojo::Headers') ? 1 : 0;
 
     my $formatted = '';
 
@@ -32,7 +32,7 @@ sub build {
         $formatted = "\x0d\x0a0\x0d\x0a";
 
         # Trailing headers
-        $formatted .= "$chunk\x0d\x0a\x0d\x0a" if $headers;
+        $formatted .= $headers ? "$chunk\x0d\x0a\x0d\x0a" : "\x0d\x0a";
     }
 
     # Separator
@@ -66,18 +66,7 @@ sub parse {
         # Last chunk
         if ($length == 0) {
             $filter->{buffer} =~ s/^$1//;
-
-            # Trailing headers
-            if ($self->headers->trailer) {
-                $self->state('trailing_headers');
-            }
-
-            # Done
-            else {
-                $self->_remove_chunked_encoding;
-                $filter->empty;
-                $self->done;
-            }
+            $self->state('trailing_headers');
             last;
         }
 
@@ -116,7 +105,10 @@ sub _remove_chunked_encoding {
     my $self     = shift;
     my $encoding = $self->headers->transfer_encoding;
     $encoding =~ s/,?\s*chunked//ig;
-    $self->headers->transfer_encoding($encoding);
+    $encoding
+      ? $self->headers->transfer_encoding($encoding)
+      : $self->headers->remove('Transfer-Encoding');
+    $self->headers->content_length($self->output_buffer->raw_length);
 }
 
 1;
