@@ -1,4 +1,4 @@
-# Copyright (C) 2008, Sebastian Riedel.
+# Copyright (C) 2008-2009, Sebastian Riedel.
 
 package Mojo::Script::DaemonPrefork;
 
@@ -9,7 +9,7 @@ use base 'Mojo::Script';
 
 use Mojo::Server::Daemon::Prefork;
 
-__PACKAGE__->attr(description => (chained => 1, default => <<'EOF'));
+__PACKAGE__->attr('description', default => <<'EOF');
 * Start the prefork daemon. *
 Takes a port as option, by default 3000 will be used.
     daemon_prefork
