@@ -8,22 +8,25 @@ use warnings;
 use base 'Mojo::Base';
 
 __PACKAGE__->attr(
-    types => (
-        chained => 1,
-        default => sub {
-            return {
-                css   => 'text/css',
-                ico   => 'image/x-icon',
-                gif   => 'image/gif',
-                html  => 'text/html',
-                jpg   => 'image/jpeg',
-                js    => 'application/x-javascript',
-                phtml => 'text/html',
-                png   => 'image/png',
-                txt   => 'text/plain'
-            };
-        }
-    )
+    'types',
+    default => sub {
+        return {
+            css  => 'text/css',
+            gif  => 'image/gif',
+            gz   => 'application/gzip',
+            htm  => 'text/html',
+            html => 'text/html',
+            ico  => 'image/x-icon',
+            jpeg => 'image/jpeg',
+            jpg  => 'image/jpeg',
+            js   => 'application/x-javascript',
+            png  => 'image/png',
+            tar  => 'application/x-tar',
+            txt  => 'text/plain',
+            xml  => 'text/xml',
+            zip  => 'application/zip'
+        };
+    }
 );
 
 # Magic. Got it.
@@ -58,6 +61,8 @@ L<MojoX::Types> is a container for MIME types.
 
 =head2 ATTRIBUTES
 
+L<MojoX::Types> implements the following attributes.
+
 =head2 C<types>
 
     my $map = $types->types;
